package com.autentia.tutos;

import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

/*
 * SampleStoredProcedures.java
 *
 * Programa de ejecuta un stored procedure de una base de datos de MySQL y pinta el valor del resulset y parametro de salida por consola.
 * Presupone que el servidor de base de datos está arrancado, disponible,
 * en el puerto por defecto.
 * El usuario y password de conexión con la base de datos debe cambiarse.
 * En la base de datos se supone que hay una base de datos llamada test y que
 * tiene un procedimiento almacenado creado de la siguiente manera:
 * mysql> create database test;
 * mysql> use test;
 * mysql> delimiter //
			CREATE PROCEDURE demoSp(IN inputParam VARCHAR(255), INOUT inOutParam INT)
			BEGIN
			    DECLARE z INT;
			    SET z = inOutParam + 1;
			    SET inOutParam = z;
			
			    SELECT inputParam;
			
			    SELECT CONCAT('zyxw', inputParam);
			END//
 */

public class SampleStoredProcedures {

	public static void main(String[] args) throws SQLException{

		Connection conn = null;
		try {
			// Creamos la conexion
			conn=ConnectionMySQL.conectar("localhost", "test", "test", "test");
			conn.setAutoCommit(false);
			
			 CallableStatement cStmt = conn.prepareCall("{call demoSp(?, ?)}");  
			 cStmt.setString(1, "abcdefg");  
			 cStmt.setInt(2, 0);
			 cStmt.registerOutParameter("inOutParam", Types.INTEGER);  
			 
			 cStmt.execute();  
			 final ResultSet rs = cStmt.getResultSet();
			 
			 while (rs.next()) {
			     System.out.println("Cadena de caracteres pasada como parametro de entrada="+rs.getString("inputParam"));
			 }  
			 
			 int outputValue = cStmt.getInt("inOutParam");; // index-based  
			 System.out.println("Parametro de salida incrementado="+outputValue);
		
			
		
		}catch (Exception e) {
			conn.rollback();
			e.printStackTrace();
		}finally{
			conn.close();
		}
	}
}
